# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: playwright.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='playwright.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10playwright.proto\"\xc2\x0c\n\x07Request\x1a\x07\n\x05\x45mpty\x1a\x45\n\x11ScreenshotOptions\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x10\n\x08selector\x18\x02 \x01(\t\x12\x10\n\x08\x66ullPage\x18\x03 \x01(\x08\x1a\x18\n\x08\x46ilePath\x12\x0c\n\x04path\x18\x01 \x01(\t\x1a\x14\n\x04Json\x12\x0c\n\x04\x62ody\x18\x01 \x01(\t\x1a\x32\n\x12MouseButtonOptions\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x0c\n\x04json\x18\x02 \x01(\t\x1a/\n\x10KeyboardKeypress\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x1a\x44\n\x14KeyboardInputOptions\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\r\n\x05input\x18\x02 \x01(\t\x12\r\n\x05\x64\x65lay\x18\x03 \x01(\x05\x1a@\n\x07\x42rowser\x12\x0f\n\x07\x62rowser\x18\x01 \x01(\t\x12\x10\n\x08headless\x18\x02 \x01(\x08\x12\x12\n\nrawOptions\x18\x03 \x01(\t\x1a\x34\n\x07\x43ontext\x12\x12\n\nrawOptions\x18\x01 \x01(\t\x12\x15\n\rhideRfBrowser\x18\x02 \x01(\x08\x1a\x12\n\x03Url\x12\x0b\n\x03url\x18\x01 \x01(\t\x1a:\n\tTextInput\x12\r\n\x05input\x18\x01 \x01(\t\x12\x10\n\x08selector\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\x08\x1a\x35\n\x0f\x45lementProperty\x12\x10\n\x08selector\x18\x01 \x01(\t\x12\x10\n\x08property\x18\x02 \x01(\t\x1aH\n\x08TypeText\x12\x10\n\x08selector\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\r\n\x05\x64\x65lay\x18\x03 \x01(\x05\x12\r\n\x05\x63lear\x18\x04 \x01(\x08\x1a*\n\x08\x46illText\x12\x10\n\x08selector\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x1a\x1d\n\tClearText\x12\x10\n\x08selector\x18\x01 \x01(\t\x1a*\n\tPressKeys\x12\x10\n\x08selector\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x03(\t\x1a#\n\x0f\x45lementSelector\x12\x10\n\x08selector\x18\x01 \x01(\t\x1a\x1a\n\x07Timeout\x12\x0f\n\x07timeout\x18\x01 \x01(\x02\x1a\x16\n\x05Index\x12\r\n\x05index\x18\x01 \x01(\t\x1a,\n\rIdWithTimeout\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07timeout\x18\x02 \x01(\x02\x1a\x1b\n\x08StyleTag\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x1a?\n\x1a\x45lementSelectorWithOptions\x12\x10\n\x08selector\x18\x01 \x01(\t\x12\x0f\n\x07options\x18\x02 \x01(\t\x1an\n\x1b\x45lementSelectorWithDuration\x12\x10\n\x08selector\x18\x01 \x01(\t\x12\x10\n\x08\x64uration\x18\x02 \x01(\x05\x12\r\n\x05width\x18\x03 \x01(\t\x12\r\n\x05style\x18\x04 \x01(\t\x12\r\n\x05\x63olor\x18\x05 \x01(\t\x1a>\n\x15SelectElementSelector\x12\x10\n\x08selector\x18\x01 \x01(\t\x12\x13\n\x0bmatcherJson\x18\x02 \x01(\t\x1a\x32\n\x0eJavascriptCode\x12\x0e\n\x06script\x18\x01 \x01(\t\x12\x10\n\x08selector\x18\x02 \x01(\t\x1aK\n\x16WaitForFunctionOptions\x12\x0e\n\x06script\x18\x01 \x01(\t\x12\x10\n\x08selector\x18\x02 \x01(\t\x12\x0f\n\x07options\x18\x03 \x01(\t\x1a \n\x10PlaywrightObject\x12\x0c\n\x04info\x18\x01 \x01(\t\x1a)\n\x08Viewport\x12\r\n\x05width\x18\x01 \x01(\x05\x12\x0e\n\x06height\x18\x02 \x01(\x05\x1aI\n\x0bHttpRequest\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0e\n\x06method\x18\x02 \x01(\t\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\x12\x0f\n\x07headers\x18\x04 \x01(\t\x1a\x36\n\x0bHttpCapture\x12\x16\n\x0eurlOrPredicate\x18\x01 \x01(\t\x12\x0f\n\x07timeout\x18\x02 \x01(\x02\x1a\x16\n\x06\x44\x65vice\x12\x0c\n\x04name\x18\x01 \x01(\t\x1a\x37\n\x0b\x41lertAction\x12\x13\n\x0b\x61lertAction\x18\x01 \x01(\t\x12\x13\n\x0bpromptInput\x18\x02 \x01(\t\x1a\x15\n\x04\x42ool\x12\r\n\x05value\x18\x01 \x01(\x08\"F\n\x05Types\x1a=\n\x0bSelectEntry\x12\r\n\x05value\x18\x02 \x01(\t\x12\r\n\x05label\x18\x03 \x01(\t\x12\x10\n\x08selected\x18\x04 \x01(\x08\"\x94\x02\n\x08Response\x1a\x14\n\x05\x45mpty\x12\x0b\n\x03log\x18\x01 \x01(\t\x1a#\n\x06String\x12\x0b\n\x03log\x18\x01 \x01(\t\x12\x0c\n\x04\x62ody\x18\x02 \x01(\t\x1a!\n\x04\x42ool\x12\x0b\n\x03log\x18\x01 \x01(\t\x12\x0c\n\x04\x62ody\x18\x02 \x01(\x08\x1a \n\x03Int\x12\x0b\n\x03log\x18\x01 \x01(\t\x12\x0c\n\x04\x62ody\x18\x02 \x01(\x05\x1a+\n\x06Select\x12!\n\x05\x65ntry\x18\x01 \x03(\x0b\x32\x12.Types.SelectEntry\x1a!\n\x04Json\x12\x0b\n\x03log\x18\x01 \x01(\t\x12\x0c\n\x04json\x18\x02 \x01(\t\x1a\x38\n\x19JavascriptExecutionResult\x12\x0b\n\x03log\x18\x01 \x01(\t\x12\x0e\n\x06result\x18\x02 \x01(\t2\xb4\x1d\n\nPlaywright\x12+\n\tAddCookie\x12\r.Request.Json\x1a\x0f.Response.Empty\x12,\n\nGetCookies\x12\x0e.Request.Empty\x1a\x0e.Response.Json\x12\x33\n\x10\x44\x65leteAllCookies\x12\x0e.Request.Empty\x1a\x0f.Response.Empty\x12>\n\x0eTakeScreenshot\x12\x1a.Request.ScreenshotOptions\x1a\x10.Response.String\x12%\n\x04GoTo\x12\x0c.Request.Url\x1a\x0f.Response.Empty\x12\'\n\x06GoBack\x12\x0c.Request.Url\x1a\x0f.Response.Empty\x12*\n\tGoForward\x12\x0c.Request.Url\x1a\x0f.Response.Empty\x12,\n\x08GetTitle\x12\x0e.Request.Empty\x1a\x10.Response.String\x12:\n\x0fGetElementCount\x12\x18.Request.ElementSelector\x1a\r.Response.Int\x12\x30\n\tInputText\x12\x12.Request.TextInput\x1a\x0f.Response.Empty\x12.\n\x08TypeText\x12\x11.Request.TypeText\x1a\x0f.Response.Empty\x12.\n\x08\x46illText\x12\x11.Request.FillText\x1a\x0f.Response.Empty\x12\x30\n\tClearText\x12\x12.Request.ClearText\x1a\x0f.Response.Empty\x12<\n\x0eGetDomProperty\x12\x18.Request.ElementProperty\x1a\x10.Response.String\x12\x41\n\x13GetElementAttribute\x12\x18.Request.ElementProperty\x1a\x10.Response.String\x12;\n\x0fGetBoolProperty\x12\x18.Request.ElementProperty\x1a\x0e.Response.Bool\x12\x31\n\x0fGetViewportSize\x12\x0e.Request.Empty\x1a\x0e.Response.Json\x12*\n\x06GetUrl\x12\x0e.Request.Empty\x1a\x10.Response.String\x12\x31\n\rGetPageSource\x12\x0e.Request.Empty\x1a\x10.Response.String\x12,\n\x05Press\x12\x12.Request.PressKeys\x1a\x0f.Response.Empty\x12>\n\x10GetSelectContent\x12\x18.Request.ElementSelector\x1a\x10.Response.Select\x12?\n\x0cSelectOption\x12\x1e.Request.SelectElementSelector\x1a\x0f.Response.Empty\x12;\n\x0e\x44\x65selectOption\x12\x18.Request.ElementSelector\x1a\x0f.Response.Empty\x12:\n\rCheckCheckbox\x12\x18.Request.ElementSelector\x1a\x0f.Response.Empty\x12<\n\x0fUncheckCheckbox\x12\x18.Request.ElementSelector\x1a\x0f.Response.Empty\x12*\n\x06Health\x12\x0e.Request.Empty\x1a\x10.Response.String\x12\x38\n\nGetElement\x12\x18.Request.ElementSelector\x1a\x10.Response.String\x12\x37\n\x0bGetElements\x12\x18.Request.ElementSelector\x1a\x0e.Response.Json\x12/\n\nSetTimeout\x12\x10.Request.Timeout\x1a\x0f.Response.Empty\x12\x31\n\x0b\x41\x64\x64StyleTag\x12\x11.Request.StyleTag\x1a\x0f.Response.Empty\x12J\n\x11HighlightElements\x12$.Request.ElementSelectorWithDuration\x1a\x0f.Response.Empty\x12*\n\x08\x44ownload\x12\x0c.Request.Url\x1a\x10.Response.String\x12=\n\x05\x43lick\x12#.Request.ElementSelectorWithOptions\x1a\x0f.Response.Empty\x12=\n\x05Hover\x12#.Request.ElementSelectorWithOptions\x1a\x0f.Response.Empty\x12\x32\n\x05\x46ocus\x12\x18.Request.ElementSelector\x1a\x0f.Response.Empty\x12L\n\x14WaitForElementsState\x12#.Request.ElementSelectorWithOptions\x1a\x0f.Response.Empty\x12\x42\n\x0fWaitForFunction\x12\x1f.Request.WaitForFunctionOptions\x1a\x0e.Response.Json\x12Q\n\x11\x45xecuteJavascript\x12\x17.Request.JavascriptCode\x1a#.Response.JavascriptExecutionResult\x12\x43\n\x0cGetPageState\x12\x0e.Request.Empty\x1a#.Response.JavascriptExecutionResult\x12\x35\n\x0fSetViewportSize\x12\x11.Request.Viewport\x1a\x0f.Response.Empty\x12\x34\n\x08GetStyle\x12\x18.Request.ElementSelector\x1a\x0e.Response.Json\x12:\n\x0eGetBoundingBox\x12\x18.Request.ElementSelector\x1a\x0e.Response.Json\x12\x33\n\x0bHttpRequest\x12\x14.Request.HttpRequest\x1a\x0e.Response.Json\x12\x38\n\x0eWaitForRequest\x12\x14.Request.HttpCapture\x1a\x10.Response.String\x12\x37\n\x0fWaitForResponse\x12\x14.Request.HttpCapture\x1a\x0e.Response.Json\x12\x34\n\x0fWaitForDownload\x12\x11.Request.FilePath\x1a\x0e.Response.Json\x12;\n\x16WaitUntilNetworkIsIdle\x12\x10.Request.Timeout\x1a\x0f.Response.Empty\x12\x30\n\x0eSetGeolocation\x12\r.Request.Json\x1a\x0f.Response.Empty\x12,\n\tGetDevice\x12\x0f.Request.Device\x1a\x0e.Response.Json\x12,\n\nGetDevices\x12\x0e.Request.Empty\x1a\x0e.Response.Json\x12\x34\n\x0bHandleAlert\x12\x14.Request.AlertAction\x1a\x0f.Response.Empty\x12;\n\x0bMouseButton\x12\x1b.Request.MouseButtonOptions\x1a\x0f.Response.Empty\x12+\n\tMouseMove\x12\r.Request.Json\x1a\x0f.Response.Empty\x12\x39\n\x0bKeyboardKey\x12\x19.Request.KeyboardKeypress\x1a\x0f.Response.Empty\x12?\n\rKeyboardInput\x12\x1d.Request.KeyboardInputOptions\x1a\x0f.Response.Empty\x12\x30\n\nUploadFile\x12\x11.Request.FilePath\x1a\x0f.Response.Empty\x12,\n\nSetOffline\x12\r.Request.Bool\x1a\x0f.Response.Empty\x12)\n\x06Reload\x12\x0e.Request.Empty\x1a\x0f.Response.Empty\x12\x36\n\nSwitchPage\x12\x16.Request.IdWithTimeout\x1a\x10.Response.String\x12\x31\n\rSwitchContext\x12\x0e.Request.Index\x1a\x10.Response.String\x12\x31\n\rSwitchBrowser\x12\x0e.Request.Index\x1a\x10.Response.String\x12)\n\x07NewPage\x12\x0c.Request.Url\x1a\x10.Response.String\x12\x30\n\nNewContext\x12\x10.Request.Context\x1a\x10.Response.String\x12\x30\n\nNewBrowser\x12\x10.Request.Browser\x1a\x10.Response.String\x12\x30\n\x0c\x43loseBrowser\x12\x0e.Request.Empty\x1a\x10.Response.String\x12\x33\n\x10\x43loseAllBrowsers\x12\x0e.Request.Empty\x1a\x0f.Response.Empty\x12/\n\x0c\x43loseContext\x12\x0e.Request.Empty\x1a\x0f.Response.Empty\x12,\n\tClosePage\x12\x0e.Request.Empty\x1a\x0f.Response.Empty\x12\x33\n\x11GetBrowserCatalog\x12\x0e.Request.Empty\x1a\x0e.Response.Jsonb\x06proto3'
)




_REQUEST_EMPTY = _descriptor.Descriptor(
  name='Empty',
  full_name='Request.Empty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32,
  serialized_end=39,
)

_REQUEST_SCREENSHOTOPTIONS = _descriptor.Descriptor(
  name='ScreenshotOptions',
  full_name='Request.ScreenshotOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='Request.ScreenshotOptions.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selector', full_name='Request.ScreenshotOptions.selector', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fullPage', full_name='Request.ScreenshotOptions.fullPage', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=41,
  serialized_end=110,
)

_REQUEST_FILEPATH = _descriptor.Descriptor(
  name='FilePath',
  full_name='Request.FilePath',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='Request.FilePath.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=112,
  serialized_end=136,
)

_REQUEST_JSON = _descriptor.Descriptor(
  name='Json',
  full_name='Request.Json',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='body', full_name='Request.Json.body', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=138,
  serialized_end=158,
)

_REQUEST_MOUSEBUTTONOPTIONS = _descriptor.Descriptor(
  name='MouseButtonOptions',
  full_name='Request.MouseButtonOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='Request.MouseButtonOptions.action', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='json', full_name='Request.MouseButtonOptions.json', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=160,
  serialized_end=210,
)

_REQUEST_KEYBOARDKEYPRESS = _descriptor.Descriptor(
  name='KeyboardKeypress',
  full_name='Request.KeyboardKeypress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='Request.KeyboardKeypress.action', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='Request.KeyboardKeypress.key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=212,
  serialized_end=259,
)

_REQUEST_KEYBOARDINPUTOPTIONS = _descriptor.Descriptor(
  name='KeyboardInputOptions',
  full_name='Request.KeyboardInputOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='Request.KeyboardInputOptions.action', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input', full_name='Request.KeyboardInputOptions.input', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delay', full_name='Request.KeyboardInputOptions.delay', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=261,
  serialized_end=329,
)

_REQUEST_BROWSER = _descriptor.Descriptor(
  name='Browser',
  full_name='Request.Browser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='browser', full_name='Request.Browser.browser', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headless', full_name='Request.Browser.headless', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rawOptions', full_name='Request.Browser.rawOptions', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=331,
  serialized_end=395,
)

_REQUEST_CONTEXT = _descriptor.Descriptor(
  name='Context',
  full_name='Request.Context',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rawOptions', full_name='Request.Context.rawOptions', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hideRfBrowser', full_name='Request.Context.hideRfBrowser', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=397,
  serialized_end=449,
)

_REQUEST_URL = _descriptor.Descriptor(
  name='Url',
  full_name='Request.Url',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='Request.Url.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=451,
  serialized_end=469,
)

_REQUEST_TEXTINPUT = _descriptor.Descriptor(
  name='TextInput',
  full_name='Request.TextInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input', full_name='Request.TextInput.input', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selector', full_name='Request.TextInput.selector', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='Request.TextInput.type', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=471,
  serialized_end=529,
)

_REQUEST_ELEMENTPROPERTY = _descriptor.Descriptor(
  name='ElementProperty',
  full_name='Request.ElementProperty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='selector', full_name='Request.ElementProperty.selector', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='property', full_name='Request.ElementProperty.property', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=531,
  serialized_end=584,
)

_REQUEST_TYPETEXT = _descriptor.Descriptor(
  name='TypeText',
  full_name='Request.TypeText',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='selector', full_name='Request.TypeText.selector', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='Request.TypeText.text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delay', full_name='Request.TypeText.delay', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear', full_name='Request.TypeText.clear', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=586,
  serialized_end=658,
)

_REQUEST_FILLTEXT = _descriptor.Descriptor(
  name='FillText',
  full_name='Request.FillText',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='selector', full_name='Request.FillText.selector', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='Request.FillText.text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=660,
  serialized_end=702,
)

_REQUEST_CLEARTEXT = _descriptor.Descriptor(
  name='ClearText',
  full_name='Request.ClearText',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='selector', full_name='Request.ClearText.selector', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=704,
  serialized_end=733,
)

_REQUEST_PRESSKEYS = _descriptor.Descriptor(
  name='PressKeys',
  full_name='Request.PressKeys',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='selector', full_name='Request.PressKeys.selector', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='Request.PressKeys.key', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=735,
  serialized_end=777,
)

_REQUEST_ELEMENTSELECTOR = _descriptor.Descriptor(
  name='ElementSelector',
  full_name='Request.ElementSelector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='selector', full_name='Request.ElementSelector.selector', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=779,
  serialized_end=814,
)

_REQUEST_TIMEOUT = _descriptor.Descriptor(
  name='Timeout',
  full_name='Request.Timeout',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeout', full_name='Request.Timeout.timeout', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=816,
  serialized_end=842,
)

_REQUEST_INDEX = _descriptor.Descriptor(
  name='Index',
  full_name='Request.Index',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='Request.Index.index', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=844,
  serialized_end=866,
)

_REQUEST_IDWITHTIMEOUT = _descriptor.Descriptor(
  name='IdWithTimeout',
  full_name='Request.IdWithTimeout',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Request.IdWithTimeout.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='Request.IdWithTimeout.timeout', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=868,
  serialized_end=912,
)

_REQUEST_STYLETAG = _descriptor.Descriptor(
  name='StyleTag',
  full_name='Request.StyleTag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='Request.StyleTag.content', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=914,
  serialized_end=941,
)

_REQUEST_ELEMENTSELECTORWITHOPTIONS = _descriptor.Descriptor(
  name='ElementSelectorWithOptions',
  full_name='Request.ElementSelectorWithOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='selector', full_name='Request.ElementSelectorWithOptions.selector', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='Request.ElementSelectorWithOptions.options', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=943,
  serialized_end=1006,
)

_REQUEST_ELEMENTSELECTORWITHDURATION = _descriptor.Descriptor(
  name='ElementSelectorWithDuration',
  full_name='Request.ElementSelectorWithDuration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='selector', full_name='Request.ElementSelectorWithDuration.selector', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration', full_name='Request.ElementSelectorWithDuration.duration', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='Request.ElementSelectorWithDuration.width', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='style', full_name='Request.ElementSelectorWithDuration.style', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color', full_name='Request.ElementSelectorWithDuration.color', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1008,
  serialized_end=1118,
)

_REQUEST_SELECTELEMENTSELECTOR = _descriptor.Descriptor(
  name='SelectElementSelector',
  full_name='Request.SelectElementSelector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='selector', full_name='Request.SelectElementSelector.selector', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcherJson', full_name='Request.SelectElementSelector.matcherJson', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1120,
  serialized_end=1182,
)

_REQUEST_JAVASCRIPTCODE = _descriptor.Descriptor(
  name='JavascriptCode',
  full_name='Request.JavascriptCode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='script', full_name='Request.JavascriptCode.script', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selector', full_name='Request.JavascriptCode.selector', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1184,
  serialized_end=1234,
)

_REQUEST_WAITFORFUNCTIONOPTIONS = _descriptor.Descriptor(
  name='WaitForFunctionOptions',
  full_name='Request.WaitForFunctionOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='script', full_name='Request.WaitForFunctionOptions.script', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selector', full_name='Request.WaitForFunctionOptions.selector', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='Request.WaitForFunctionOptions.options', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1236,
  serialized_end=1311,
)

_REQUEST_PLAYWRIGHTOBJECT = _descriptor.Descriptor(
  name='PlaywrightObject',
  full_name='Request.PlaywrightObject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='Request.PlaywrightObject.info', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1313,
  serialized_end=1345,
)

_REQUEST_VIEWPORT = _descriptor.Descriptor(
  name='Viewport',
  full_name='Request.Viewport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='width', full_name='Request.Viewport.width', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='Request.Viewport.height', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1347,
  serialized_end=1388,
)

_REQUEST_HTTPREQUEST = _descriptor.Descriptor(
  name='HttpRequest',
  full_name='Request.HttpRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='Request.HttpRequest.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='method', full_name='Request.HttpRequest.method', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='Request.HttpRequest.body', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers', full_name='Request.HttpRequest.headers', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1390,
  serialized_end=1463,
)

_REQUEST_HTTPCAPTURE = _descriptor.Descriptor(
  name='HttpCapture',
  full_name='Request.HttpCapture',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='urlOrPredicate', full_name='Request.HttpCapture.urlOrPredicate', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='Request.HttpCapture.timeout', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1465,
  serialized_end=1519,
)

_REQUEST_DEVICE = _descriptor.Descriptor(
  name='Device',
  full_name='Request.Device',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Request.Device.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1521,
  serialized_end=1543,
)

_REQUEST_ALERTACTION = _descriptor.Descriptor(
  name='AlertAction',
  full_name='Request.AlertAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='alertAction', full_name='Request.AlertAction.alertAction', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='promptInput', full_name='Request.AlertAction.promptInput', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1545,
  serialized_end=1600,
)

_REQUEST_BOOL = _descriptor.Descriptor(
  name='Bool',
  full_name='Request.Bool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='Request.Bool.value', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1602,
  serialized_end=1623,
)

_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_REQUEST_EMPTY, _REQUEST_SCREENSHOTOPTIONS, _REQUEST_FILEPATH, _REQUEST_JSON, _REQUEST_MOUSEBUTTONOPTIONS, _REQUEST_KEYBOARDKEYPRESS, _REQUEST_KEYBOARDINPUTOPTIONS, _REQUEST_BROWSER, _REQUEST_CONTEXT, _REQUEST_URL, _REQUEST_TEXTINPUT, _REQUEST_ELEMENTPROPERTY, _REQUEST_TYPETEXT, _REQUEST_FILLTEXT, _REQUEST_CLEARTEXT, _REQUEST_PRESSKEYS, _REQUEST_ELEMENTSELECTOR, _REQUEST_TIMEOUT, _REQUEST_INDEX, _REQUEST_IDWITHTIMEOUT, _REQUEST_STYLETAG, _REQUEST_ELEMENTSELECTORWITHOPTIONS, _REQUEST_ELEMENTSELECTORWITHDURATION, _REQUEST_SELECTELEMENTSELECTOR, _REQUEST_JAVASCRIPTCODE, _REQUEST_WAITFORFUNCTIONOPTIONS, _REQUEST_PLAYWRIGHTOBJECT, _REQUEST_VIEWPORT, _REQUEST_HTTPREQUEST, _REQUEST_HTTPCAPTURE, _REQUEST_DEVICE, _REQUEST_ALERTACTION, _REQUEST_BOOL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21,
  serialized_end=1623,
)


_TYPES_SELECTENTRY = _descriptor.Descriptor(
  name='SelectEntry',
  full_name='Types.SelectEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='Types.SelectEntry.value', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='Types.SelectEntry.label', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selected', full_name='Types.SelectEntry.selected', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1634,
  serialized_end=1695,
)

_TYPES = _descriptor.Descriptor(
  name='Types',
  full_name='Types',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_TYPES_SELECTENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1625,
  serialized_end=1695,
)


_RESPONSE_EMPTY = _descriptor.Descriptor(
  name='Empty',
  full_name='Response.Empty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log', full_name='Response.Empty.log', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1710,
  serialized_end=1730,
)

_RESPONSE_STRING = _descriptor.Descriptor(
  name='String',
  full_name='Response.String',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log', full_name='Response.String.log', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='Response.String.body', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1732,
  serialized_end=1767,
)

_RESPONSE_BOOL = _descriptor.Descriptor(
  name='Bool',
  full_name='Response.Bool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log', full_name='Response.Bool.log', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='Response.Bool.body', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1769,
  serialized_end=1802,
)

_RESPONSE_INT = _descriptor.Descriptor(
  name='Int',
  full_name='Response.Int',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log', full_name='Response.Int.log', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='Response.Int.body', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1804,
  serialized_end=1836,
)

_RESPONSE_SELECT = _descriptor.Descriptor(
  name='Select',
  full_name='Response.Select',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entry', full_name='Response.Select.entry', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1838,
  serialized_end=1881,
)

_RESPONSE_JSON = _descriptor.Descriptor(
  name='Json',
  full_name='Response.Json',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log', full_name='Response.Json.log', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='json', full_name='Response.Json.json', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1883,
  serialized_end=1916,
)

_RESPONSE_JAVASCRIPTEXECUTIONRESULT = _descriptor.Descriptor(
  name='JavascriptExecutionResult',
  full_name='Response.JavascriptExecutionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log', full_name='Response.JavascriptExecutionResult.log', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result', full_name='Response.JavascriptExecutionResult.result', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1918,
  serialized_end=1974,
)

_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_RESPONSE_EMPTY, _RESPONSE_STRING, _RESPONSE_BOOL, _RESPONSE_INT, _RESPONSE_SELECT, _RESPONSE_JSON, _RESPONSE_JAVASCRIPTEXECUTIONRESULT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1698,
  serialized_end=1974,
)

_REQUEST_EMPTY.containing_type = _REQUEST
_REQUEST_SCREENSHOTOPTIONS.containing_type = _REQUEST
_REQUEST_FILEPATH.containing_type = _REQUEST
_REQUEST_JSON.containing_type = _REQUEST
_REQUEST_MOUSEBUTTONOPTIONS.containing_type = _REQUEST
_REQUEST_KEYBOARDKEYPRESS.containing_type = _REQUEST
_REQUEST_KEYBOARDINPUTOPTIONS.containing_type = _REQUEST
_REQUEST_BROWSER.containing_type = _REQUEST
_REQUEST_CONTEXT.containing_type = _REQUEST
_REQUEST_URL.containing_type = _REQUEST
_REQUEST_TEXTINPUT.containing_type = _REQUEST
_REQUEST_ELEMENTPROPERTY.containing_type = _REQUEST
_REQUEST_TYPETEXT.containing_type = _REQUEST
_REQUEST_FILLTEXT.containing_type = _REQUEST
_REQUEST_CLEARTEXT.containing_type = _REQUEST
_REQUEST_PRESSKEYS.containing_type = _REQUEST
_REQUEST_ELEMENTSELECTOR.containing_type = _REQUEST
_REQUEST_TIMEOUT.containing_type = _REQUEST
_REQUEST_INDEX.containing_type = _REQUEST
_REQUEST_IDWITHTIMEOUT.containing_type = _REQUEST
_REQUEST_STYLETAG.containing_type = _REQUEST
_REQUEST_ELEMENTSELECTORWITHOPTIONS.containing_type = _REQUEST
_REQUEST_ELEMENTSELECTORWITHDURATION.containing_type = _REQUEST
_REQUEST_SELECTELEMENTSELECTOR.containing_type = _REQUEST
_REQUEST_JAVASCRIPTCODE.containing_type = _REQUEST
_REQUEST_WAITFORFUNCTIONOPTIONS.containing_type = _REQUEST
_REQUEST_PLAYWRIGHTOBJECT.containing_type = _REQUEST
_REQUEST_VIEWPORT.containing_type = _REQUEST
_REQUEST_HTTPREQUEST.containing_type = _REQUEST
_REQUEST_HTTPCAPTURE.containing_type = _REQUEST
_REQUEST_DEVICE.containing_type = _REQUEST
_REQUEST_ALERTACTION.containing_type = _REQUEST
_REQUEST_BOOL.containing_type = _REQUEST
_TYPES_SELECTENTRY.containing_type = _TYPES
_RESPONSE_EMPTY.containing_type = _RESPONSE
_RESPONSE_STRING.containing_type = _RESPONSE
_RESPONSE_BOOL.containing_type = _RESPONSE
_RESPONSE_INT.containing_type = _RESPONSE
_RESPONSE_SELECT.fields_by_name['entry'].message_type = _TYPES_SELECTENTRY
_RESPONSE_SELECT.containing_type = _RESPONSE
_RESPONSE_JSON.containing_type = _RESPONSE
_RESPONSE_JAVASCRIPTEXECUTIONRESULT.containing_type = _RESPONSE
DESCRIPTOR.message_types_by_name['Request'] = _REQUEST
DESCRIPTOR.message_types_by_name['Types'] = _TYPES
DESCRIPTOR.message_types_by_name['Response'] = _RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Request = _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {

  'Empty' : _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_EMPTY,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.Empty)
    })
  ,

  'ScreenshotOptions' : _reflection.GeneratedProtocolMessageType('ScreenshotOptions', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_SCREENSHOTOPTIONS,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.ScreenshotOptions)
    })
  ,

  'FilePath' : _reflection.GeneratedProtocolMessageType('FilePath', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_FILEPATH,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.FilePath)
    })
  ,

  'Json' : _reflection.GeneratedProtocolMessageType('Json', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_JSON,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.Json)
    })
  ,

  'MouseButtonOptions' : _reflection.GeneratedProtocolMessageType('MouseButtonOptions', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_MOUSEBUTTONOPTIONS,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.MouseButtonOptions)
    })
  ,

  'KeyboardKeypress' : _reflection.GeneratedProtocolMessageType('KeyboardKeypress', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_KEYBOARDKEYPRESS,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.KeyboardKeypress)
    })
  ,

  'KeyboardInputOptions' : _reflection.GeneratedProtocolMessageType('KeyboardInputOptions', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_KEYBOARDINPUTOPTIONS,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.KeyboardInputOptions)
    })
  ,

  'Browser' : _reflection.GeneratedProtocolMessageType('Browser', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_BROWSER,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.Browser)
    })
  ,

  'Context' : _reflection.GeneratedProtocolMessageType('Context', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_CONTEXT,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.Context)
    })
  ,

  'Url' : _reflection.GeneratedProtocolMessageType('Url', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_URL,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.Url)
    })
  ,

  'TextInput' : _reflection.GeneratedProtocolMessageType('TextInput', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_TEXTINPUT,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.TextInput)
    })
  ,

  'ElementProperty' : _reflection.GeneratedProtocolMessageType('ElementProperty', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_ELEMENTPROPERTY,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.ElementProperty)
    })
  ,

  'TypeText' : _reflection.GeneratedProtocolMessageType('TypeText', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_TYPETEXT,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.TypeText)
    })
  ,

  'FillText' : _reflection.GeneratedProtocolMessageType('FillText', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_FILLTEXT,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.FillText)
    })
  ,

  'ClearText' : _reflection.GeneratedProtocolMessageType('ClearText', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_CLEARTEXT,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.ClearText)
    })
  ,

  'PressKeys' : _reflection.GeneratedProtocolMessageType('PressKeys', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_PRESSKEYS,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.PressKeys)
    })
  ,

  'ElementSelector' : _reflection.GeneratedProtocolMessageType('ElementSelector', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_ELEMENTSELECTOR,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.ElementSelector)
    })
  ,

  'Timeout' : _reflection.GeneratedProtocolMessageType('Timeout', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_TIMEOUT,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.Timeout)
    })
  ,

  'Index' : _reflection.GeneratedProtocolMessageType('Index', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_INDEX,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.Index)
    })
  ,

  'IdWithTimeout' : _reflection.GeneratedProtocolMessageType('IdWithTimeout', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_IDWITHTIMEOUT,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.IdWithTimeout)
    })
  ,

  'StyleTag' : _reflection.GeneratedProtocolMessageType('StyleTag', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_STYLETAG,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.StyleTag)
    })
  ,

  'ElementSelectorWithOptions' : _reflection.GeneratedProtocolMessageType('ElementSelectorWithOptions', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_ELEMENTSELECTORWITHOPTIONS,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.ElementSelectorWithOptions)
    })
  ,

  'ElementSelectorWithDuration' : _reflection.GeneratedProtocolMessageType('ElementSelectorWithDuration', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_ELEMENTSELECTORWITHDURATION,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.ElementSelectorWithDuration)
    })
  ,

  'SelectElementSelector' : _reflection.GeneratedProtocolMessageType('SelectElementSelector', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_SELECTELEMENTSELECTOR,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.SelectElementSelector)
    })
  ,

  'JavascriptCode' : _reflection.GeneratedProtocolMessageType('JavascriptCode', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_JAVASCRIPTCODE,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.JavascriptCode)
    })
  ,

  'WaitForFunctionOptions' : _reflection.GeneratedProtocolMessageType('WaitForFunctionOptions', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_WAITFORFUNCTIONOPTIONS,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.WaitForFunctionOptions)
    })
  ,

  'PlaywrightObject' : _reflection.GeneratedProtocolMessageType('PlaywrightObject', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_PLAYWRIGHTOBJECT,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.PlaywrightObject)
    })
  ,

  'Viewport' : _reflection.GeneratedProtocolMessageType('Viewport', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_VIEWPORT,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.Viewport)
    })
  ,

  'HttpRequest' : _reflection.GeneratedProtocolMessageType('HttpRequest', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_HTTPREQUEST,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.HttpRequest)
    })
  ,

  'HttpCapture' : _reflection.GeneratedProtocolMessageType('HttpCapture', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_HTTPCAPTURE,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.HttpCapture)
    })
  ,

  'Device' : _reflection.GeneratedProtocolMessageType('Device', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_DEVICE,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.Device)
    })
  ,

  'AlertAction' : _reflection.GeneratedProtocolMessageType('AlertAction', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_ALERTACTION,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.AlertAction)
    })
  ,

  'Bool' : _reflection.GeneratedProtocolMessageType('Bool', (_message.Message,), {
    'DESCRIPTOR' : _REQUEST_BOOL,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Request.Bool)
    })
  ,
  'DESCRIPTOR' : _REQUEST,
  '__module__' : 'playwright_pb2'
  # @@protoc_insertion_point(class_scope:Request)
  })
_sym_db.RegisterMessage(Request)
_sym_db.RegisterMessage(Request.Empty)
_sym_db.RegisterMessage(Request.ScreenshotOptions)
_sym_db.RegisterMessage(Request.FilePath)
_sym_db.RegisterMessage(Request.Json)
_sym_db.RegisterMessage(Request.MouseButtonOptions)
_sym_db.RegisterMessage(Request.KeyboardKeypress)
_sym_db.RegisterMessage(Request.KeyboardInputOptions)
_sym_db.RegisterMessage(Request.Browser)
_sym_db.RegisterMessage(Request.Context)
_sym_db.RegisterMessage(Request.Url)
_sym_db.RegisterMessage(Request.TextInput)
_sym_db.RegisterMessage(Request.ElementProperty)
_sym_db.RegisterMessage(Request.TypeText)
_sym_db.RegisterMessage(Request.FillText)
_sym_db.RegisterMessage(Request.ClearText)
_sym_db.RegisterMessage(Request.PressKeys)
_sym_db.RegisterMessage(Request.ElementSelector)
_sym_db.RegisterMessage(Request.Timeout)
_sym_db.RegisterMessage(Request.Index)
_sym_db.RegisterMessage(Request.IdWithTimeout)
_sym_db.RegisterMessage(Request.StyleTag)
_sym_db.RegisterMessage(Request.ElementSelectorWithOptions)
_sym_db.RegisterMessage(Request.ElementSelectorWithDuration)
_sym_db.RegisterMessage(Request.SelectElementSelector)
_sym_db.RegisterMessage(Request.JavascriptCode)
_sym_db.RegisterMessage(Request.WaitForFunctionOptions)
_sym_db.RegisterMessage(Request.PlaywrightObject)
_sym_db.RegisterMessage(Request.Viewport)
_sym_db.RegisterMessage(Request.HttpRequest)
_sym_db.RegisterMessage(Request.HttpCapture)
_sym_db.RegisterMessage(Request.Device)
_sym_db.RegisterMessage(Request.AlertAction)
_sym_db.RegisterMessage(Request.Bool)

Types = _reflection.GeneratedProtocolMessageType('Types', (_message.Message,), {

  'SelectEntry' : _reflection.GeneratedProtocolMessageType('SelectEntry', (_message.Message,), {
    'DESCRIPTOR' : _TYPES_SELECTENTRY,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Types.SelectEntry)
    })
  ,
  'DESCRIPTOR' : _TYPES,
  '__module__' : 'playwright_pb2'
  # @@protoc_insertion_point(class_scope:Types)
  })
_sym_db.RegisterMessage(Types)
_sym_db.RegisterMessage(Types.SelectEntry)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {

  'Empty' : _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), {
    'DESCRIPTOR' : _RESPONSE_EMPTY,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Response.Empty)
    })
  ,

  'String' : _reflection.GeneratedProtocolMessageType('String', (_message.Message,), {
    'DESCRIPTOR' : _RESPONSE_STRING,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Response.String)
    })
  ,

  'Bool' : _reflection.GeneratedProtocolMessageType('Bool', (_message.Message,), {
    'DESCRIPTOR' : _RESPONSE_BOOL,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Response.Bool)
    })
  ,

  'Int' : _reflection.GeneratedProtocolMessageType('Int', (_message.Message,), {
    'DESCRIPTOR' : _RESPONSE_INT,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Response.Int)
    })
  ,

  'Select' : _reflection.GeneratedProtocolMessageType('Select', (_message.Message,), {
    'DESCRIPTOR' : _RESPONSE_SELECT,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Response.Select)
    })
  ,

  'Json' : _reflection.GeneratedProtocolMessageType('Json', (_message.Message,), {
    'DESCRIPTOR' : _RESPONSE_JSON,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Response.Json)
    })
  ,

  'JavascriptExecutionResult' : _reflection.GeneratedProtocolMessageType('JavascriptExecutionResult', (_message.Message,), {
    'DESCRIPTOR' : _RESPONSE_JAVASCRIPTEXECUTIONRESULT,
    '__module__' : 'playwright_pb2'
    # @@protoc_insertion_point(class_scope:Response.JavascriptExecutionResult)
    })
  ,
  'DESCRIPTOR' : _RESPONSE,
  '__module__' : 'playwright_pb2'
  # @@protoc_insertion_point(class_scope:Response)
  })
_sym_db.RegisterMessage(Response)
_sym_db.RegisterMessage(Response.Empty)
_sym_db.RegisterMessage(Response.String)
_sym_db.RegisterMessage(Response.Bool)
_sym_db.RegisterMessage(Response.Int)
_sym_db.RegisterMessage(Response.Select)
_sym_db.RegisterMessage(Response.Json)
_sym_db.RegisterMessage(Response.JavascriptExecutionResult)



_PLAYWRIGHT = _descriptor.ServiceDescriptor(
  name='Playwright',
  full_name='Playwright',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1977,
  serialized_end=5741,
  methods=[
  _descriptor.MethodDescriptor(
    name='AddCookie',
    full_name='Playwright.AddCookie',
    index=0,
    containing_service=None,
    input_type=_REQUEST_JSON,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCookies',
    full_name='Playwright.GetCookies',
    index=1,
    containing_service=None,
    input_type=_REQUEST_EMPTY,
    output_type=_RESPONSE_JSON,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAllCookies',
    full_name='Playwright.DeleteAllCookies',
    index=2,
    containing_service=None,
    input_type=_REQUEST_EMPTY,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TakeScreenshot',
    full_name='Playwright.TakeScreenshot',
    index=3,
    containing_service=None,
    input_type=_REQUEST_SCREENSHOTOPTIONS,
    output_type=_RESPONSE_STRING,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GoTo',
    full_name='Playwright.GoTo',
    index=4,
    containing_service=None,
    input_type=_REQUEST_URL,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GoBack',
    full_name='Playwright.GoBack',
    index=5,
    containing_service=None,
    input_type=_REQUEST_URL,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GoForward',
    full_name='Playwright.GoForward',
    index=6,
    containing_service=None,
    input_type=_REQUEST_URL,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTitle',
    full_name='Playwright.GetTitle',
    index=7,
    containing_service=None,
    input_type=_REQUEST_EMPTY,
    output_type=_RESPONSE_STRING,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetElementCount',
    full_name='Playwright.GetElementCount',
    index=8,
    containing_service=None,
    input_type=_REQUEST_ELEMENTSELECTOR,
    output_type=_RESPONSE_INT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='InputText',
    full_name='Playwright.InputText',
    index=9,
    containing_service=None,
    input_type=_REQUEST_TEXTINPUT,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TypeText',
    full_name='Playwright.TypeText',
    index=10,
    containing_service=None,
    input_type=_REQUEST_TYPETEXT,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FillText',
    full_name='Playwright.FillText',
    index=11,
    containing_service=None,
    input_type=_REQUEST_FILLTEXT,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ClearText',
    full_name='Playwright.ClearText',
    index=12,
    containing_service=None,
    input_type=_REQUEST_CLEARTEXT,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDomProperty',
    full_name='Playwright.GetDomProperty',
    index=13,
    containing_service=None,
    input_type=_REQUEST_ELEMENTPROPERTY,
    output_type=_RESPONSE_STRING,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetElementAttribute',
    full_name='Playwright.GetElementAttribute',
    index=14,
    containing_service=None,
    input_type=_REQUEST_ELEMENTPROPERTY,
    output_type=_RESPONSE_STRING,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBoolProperty',
    full_name='Playwright.GetBoolProperty',
    index=15,
    containing_service=None,
    input_type=_REQUEST_ELEMENTPROPERTY,
    output_type=_RESPONSE_BOOL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetViewportSize',
    full_name='Playwright.GetViewportSize',
    index=16,
    containing_service=None,
    input_type=_REQUEST_EMPTY,
    output_type=_RESPONSE_JSON,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetUrl',
    full_name='Playwright.GetUrl',
    index=17,
    containing_service=None,
    input_type=_REQUEST_EMPTY,
    output_type=_RESPONSE_STRING,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPageSource',
    full_name='Playwright.GetPageSource',
    index=18,
    containing_service=None,
    input_type=_REQUEST_EMPTY,
    output_type=_RESPONSE_STRING,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Press',
    full_name='Playwright.Press',
    index=19,
    containing_service=None,
    input_type=_REQUEST_PRESSKEYS,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSelectContent',
    full_name='Playwright.GetSelectContent',
    index=20,
    containing_service=None,
    input_type=_REQUEST_ELEMENTSELECTOR,
    output_type=_RESPONSE_SELECT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SelectOption',
    full_name='Playwright.SelectOption',
    index=21,
    containing_service=None,
    input_type=_REQUEST_SELECTELEMENTSELECTOR,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeselectOption',
    full_name='Playwright.DeselectOption',
    index=22,
    containing_service=None,
    input_type=_REQUEST_ELEMENTSELECTOR,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CheckCheckbox',
    full_name='Playwright.CheckCheckbox',
    index=23,
    containing_service=None,
    input_type=_REQUEST_ELEMENTSELECTOR,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UncheckCheckbox',
    full_name='Playwright.UncheckCheckbox',
    index=24,
    containing_service=None,
    input_type=_REQUEST_ELEMENTSELECTOR,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Health',
    full_name='Playwright.Health',
    index=25,
    containing_service=None,
    input_type=_REQUEST_EMPTY,
    output_type=_RESPONSE_STRING,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetElement',
    full_name='Playwright.GetElement',
    index=26,
    containing_service=None,
    input_type=_REQUEST_ELEMENTSELECTOR,
    output_type=_RESPONSE_STRING,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetElements',
    full_name='Playwright.GetElements',
    index=27,
    containing_service=None,
    input_type=_REQUEST_ELEMENTSELECTOR,
    output_type=_RESPONSE_JSON,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetTimeout',
    full_name='Playwright.SetTimeout',
    index=28,
    containing_service=None,
    input_type=_REQUEST_TIMEOUT,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddStyleTag',
    full_name='Playwright.AddStyleTag',
    index=29,
    containing_service=None,
    input_type=_REQUEST_STYLETAG,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='HighlightElements',
    full_name='Playwright.HighlightElements',
    index=30,
    containing_service=None,
    input_type=_REQUEST_ELEMENTSELECTORWITHDURATION,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Download',
    full_name='Playwright.Download',
    index=31,
    containing_service=None,
    input_type=_REQUEST_URL,
    output_type=_RESPONSE_STRING,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Click',
    full_name='Playwright.Click',
    index=32,
    containing_service=None,
    input_type=_REQUEST_ELEMENTSELECTORWITHOPTIONS,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Hover',
    full_name='Playwright.Hover',
    index=33,
    containing_service=None,
    input_type=_REQUEST_ELEMENTSELECTORWITHOPTIONS,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Focus',
    full_name='Playwright.Focus',
    index=34,
    containing_service=None,
    input_type=_REQUEST_ELEMENTSELECTOR,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WaitForElementsState',
    full_name='Playwright.WaitForElementsState',
    index=35,
    containing_service=None,
    input_type=_REQUEST_ELEMENTSELECTORWITHOPTIONS,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WaitForFunction',
    full_name='Playwright.WaitForFunction',
    index=36,
    containing_service=None,
    input_type=_REQUEST_WAITFORFUNCTIONOPTIONS,
    output_type=_RESPONSE_JSON,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ExecuteJavascript',
    full_name='Playwright.ExecuteJavascript',
    index=37,
    containing_service=None,
    input_type=_REQUEST_JAVASCRIPTCODE,
    output_type=_RESPONSE_JAVASCRIPTEXECUTIONRESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPageState',
    full_name='Playwright.GetPageState',
    index=38,
    containing_service=None,
    input_type=_REQUEST_EMPTY,
    output_type=_RESPONSE_JAVASCRIPTEXECUTIONRESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetViewportSize',
    full_name='Playwright.SetViewportSize',
    index=39,
    containing_service=None,
    input_type=_REQUEST_VIEWPORT,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetStyle',
    full_name='Playwright.GetStyle',
    index=40,
    containing_service=None,
    input_type=_REQUEST_ELEMENTSELECTOR,
    output_type=_RESPONSE_JSON,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBoundingBox',
    full_name='Playwright.GetBoundingBox',
    index=41,
    containing_service=None,
    input_type=_REQUEST_ELEMENTSELECTOR,
    output_type=_RESPONSE_JSON,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='HttpRequest',
    full_name='Playwright.HttpRequest',
    index=42,
    containing_service=None,
    input_type=_REQUEST_HTTPREQUEST,
    output_type=_RESPONSE_JSON,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WaitForRequest',
    full_name='Playwright.WaitForRequest',
    index=43,
    containing_service=None,
    input_type=_REQUEST_HTTPCAPTURE,
    output_type=_RESPONSE_STRING,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WaitForResponse',
    full_name='Playwright.WaitForResponse',
    index=44,
    containing_service=None,
    input_type=_REQUEST_HTTPCAPTURE,
    output_type=_RESPONSE_JSON,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WaitForDownload',
    full_name='Playwright.WaitForDownload',
    index=45,
    containing_service=None,
    input_type=_REQUEST_FILEPATH,
    output_type=_RESPONSE_JSON,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WaitUntilNetworkIsIdle',
    full_name='Playwright.WaitUntilNetworkIsIdle',
    index=46,
    containing_service=None,
    input_type=_REQUEST_TIMEOUT,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetGeolocation',
    full_name='Playwright.SetGeolocation',
    index=47,
    containing_service=None,
    input_type=_REQUEST_JSON,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDevice',
    full_name='Playwright.GetDevice',
    index=48,
    containing_service=None,
    input_type=_REQUEST_DEVICE,
    output_type=_RESPONSE_JSON,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDevices',
    full_name='Playwright.GetDevices',
    index=49,
    containing_service=None,
    input_type=_REQUEST_EMPTY,
    output_type=_RESPONSE_JSON,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='HandleAlert',
    full_name='Playwright.HandleAlert',
    index=50,
    containing_service=None,
    input_type=_REQUEST_ALERTACTION,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MouseButton',
    full_name='Playwright.MouseButton',
    index=51,
    containing_service=None,
    input_type=_REQUEST_MOUSEBUTTONOPTIONS,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MouseMove',
    full_name='Playwright.MouseMove',
    index=52,
    containing_service=None,
    input_type=_REQUEST_JSON,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='KeyboardKey',
    full_name='Playwright.KeyboardKey',
    index=53,
    containing_service=None,
    input_type=_REQUEST_KEYBOARDKEYPRESS,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='KeyboardInput',
    full_name='Playwright.KeyboardInput',
    index=54,
    containing_service=None,
    input_type=_REQUEST_KEYBOARDINPUTOPTIONS,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UploadFile',
    full_name='Playwright.UploadFile',
    index=55,
    containing_service=None,
    input_type=_REQUEST_FILEPATH,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetOffline',
    full_name='Playwright.SetOffline',
    index=56,
    containing_service=None,
    input_type=_REQUEST_BOOL,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Reload',
    full_name='Playwright.Reload',
    index=57,
    containing_service=None,
    input_type=_REQUEST_EMPTY,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SwitchPage',
    full_name='Playwright.SwitchPage',
    index=58,
    containing_service=None,
    input_type=_REQUEST_IDWITHTIMEOUT,
    output_type=_RESPONSE_STRING,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SwitchContext',
    full_name='Playwright.SwitchContext',
    index=59,
    containing_service=None,
    input_type=_REQUEST_INDEX,
    output_type=_RESPONSE_STRING,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SwitchBrowser',
    full_name='Playwright.SwitchBrowser',
    index=60,
    containing_service=None,
    input_type=_REQUEST_INDEX,
    output_type=_RESPONSE_STRING,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NewPage',
    full_name='Playwright.NewPage',
    index=61,
    containing_service=None,
    input_type=_REQUEST_URL,
    output_type=_RESPONSE_STRING,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NewContext',
    full_name='Playwright.NewContext',
    index=62,
    containing_service=None,
    input_type=_REQUEST_CONTEXT,
    output_type=_RESPONSE_STRING,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NewBrowser',
    full_name='Playwright.NewBrowser',
    index=63,
    containing_service=None,
    input_type=_REQUEST_BROWSER,
    output_type=_RESPONSE_STRING,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CloseBrowser',
    full_name='Playwright.CloseBrowser',
    index=64,
    containing_service=None,
    input_type=_REQUEST_EMPTY,
    output_type=_RESPONSE_STRING,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CloseAllBrowsers',
    full_name='Playwright.CloseAllBrowsers',
    index=65,
    containing_service=None,
    input_type=_REQUEST_EMPTY,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CloseContext',
    full_name='Playwright.CloseContext',
    index=66,
    containing_service=None,
    input_type=_REQUEST_EMPTY,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ClosePage',
    full_name='Playwright.ClosePage',
    index=67,
    containing_service=None,
    input_type=_REQUEST_EMPTY,
    output_type=_RESPONSE_EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBrowserCatalog',
    full_name='Playwright.GetBrowserCatalog',
    index=68,
    containing_service=None,
    input_type=_REQUEST_EMPTY,
    output_type=_RESPONSE_JSON,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PLAYWRIGHT)

DESCRIPTOR.services_by_name['Playwright'] = _PLAYWRIGHT

# @@protoc_insertion_point(module_scope)



# Copyright 2020-     Robot Framework Foundation
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json
from datetime import timedelta
from pathlib import Path
from typing import Dict, Optional, Union

from robotlibcore import keyword  # type: ignore

from ..base import LibraryComponent
from ..generated.playwright_pb2 import Request
from ..utils import ElementState, logger


class Waiter(LibraryComponent):
    @keyword(tags=["Wait", "PageContent"])
    def wait_for_elements_state(
        self,
        selector: str,
        state: ElementState = ElementState.visible,
        timeout: Optional[timedelta] = None,
    ):
        """Waits for the element found by ``selector`` to satisfy state option.

        State options could be either appear/disappear from dom, or become visible/hidden.
        If at the moment of calling the keyword, the selector already satisfies the condition,
        the keyword will return immediately.

        If the selector doesn't satisfy the condition within the timeout the keyword will FAIL.

        ``selector`` <str> Selector of the corresponding object. **Required**
        See the `Finding elements` section for details about the selectors.

        ``state`` Defaults to visible. Possible states are:
        - ``attached``: to be present in DOM.
        - ``detached``: to not be present in DOM.
        - ``visible``: to have non-empty bounding box and no visibility:hidden.
        - ``hidden``: to be detached from DOM, or have an empty bounding box or visibility:hidden.
        - ``enabled``: to not be ``disabled``.
        - ``disabled``: to be ``disabled``. Can be used on <button>, <fieldset>, <input>, <optgroup>, <option>, <select> and <textarea>.
        - ``editable``: to not be ``readOnly``.
        - ``readonly``: to be ``readOnly``. Can be used on <input> and <textarea>.
        - ``selected``: to be ``selected``. Can be used on <option>.
        - ``deselected``: to not be ``selected``.
        - ``focused``: to be the ``activeElement``.
        - ``defocused``: to not be the ``activeElement``.
        - ``checked``: to be ``checked``. Can be used on <input>.
        - ``unchecked``: to not be ``checked``.

        Note that element without any content or with display:none has an empty bounding box
        and is not considered visible.

        ``timeout`` <str> (optional) uses default timeout of 10 seconds if not set.
        """
        funct = {
            ElementState.enabled: "e => !e.disabled",
            ElementState.disabled: "e => e.disabled",
            ElementState.editable: "e => !e.readOnly",
            ElementState.readonly: "e => e.readOnly",
            ElementState.selected: "e => e.selected",
            ElementState.deselected: "e => !e.selected",
            ElementState.focused: "e => document.activeElement === e",
            ElementState.defocused: "e => document.activeElement !== e",
            ElementState.checked: "e => e.checked",
            ElementState.unchecked: "e => !e.checked",
        }

        with self.playwright.grpc_channel() as stub:
            if state in [
                ElementState.attached,
                ElementState.detached,
                ElementState.visible,
                ElementState.hidden,
            ]:
                options: Dict[str, object] = {"state": state.name}
                if timeout:
                    options["timeout"] = self.get_timeout(timeout)
                options_json = json.dumps(options)
                response = stub.WaitForElementsState(
                    Request().ElementSelectorWithOptions(
                        selector=selector, options=options_json
                    )
                )
                logger.info(response.log)
            else:
                self.wait_for_function(funct[state], selector=selector, timeout=timeout)

    @keyword(tags=["Wait", "PageContent"])
    def wait_for_function(
        self,
        function: str,
        selector: str = "",
        polling: Union[str, timedelta] = "raf",
        timeout: Optional[timedelta] = None,
    ):
        """Polls JavaScript expression or function in browser until it returns a
        (JavaScript) truthy value.

        ``function`` <str> A valid javascript function or a javascript function body. For example
        ``() => true`` and ``true`` will behave similarly. **Required**

        ``selector`` <str> Selector to resolve and pass to the JavaScript function. This will be the first
        argument the function receives. If given a selector a function is necessary, with an argument
        to capture the elementhandle. For example ``(element) => document.activeElement === element``
        See the `Finding elements` section for details about the selectors.

        ``polling`` <str> Default polling value of "raf" polls in a callback for ``requestAnimationFrame``.
        Any other value for polling will be parsed as a robot framework time for interval between polls.

        ``timeout`` <str> Uses default timeout of 10 seconds if not set.

        Example usage:
        | ${promise}    Promise To      Wait For Function    element => element.style.width=="100%"    selector=\\#progress_bar    timeout=4s
        | Click         \\#progress_bar
        | Wait For      ${promise}
        """
        with self.playwright.grpc_channel() as stub:
            options: Dict[str, int] = {}
            if polling != "raf":
                options["polling"] = self.convert_timeout(polling)  # type: ignore
            if timeout:
                options["timeout"] = self.convert_timeout(timeout)  # type: ignore
            options_json = json.dumps(options)
            response = stub.WaitForFunction(
                Request().WaitForFunctionOptions(
                    script=function,
                    selector=selector,
                    options=options_json,
                )
            )
            logger.debug(response.json)
            logger.info(response.log)

    @keyword(tags=["Wait", "BrowserControl"])
    def wait_for_download(self, saveAs: str = "") -> str:
        """Waits for next download event on page. Returns file path to downloaded file.

        To enable downloads context's ``acceptDownloads`` needs to be true.

        With default filepath downloaded files are deleted when Context the download happened in is closed.

        ``saveAs`` <str> Filename to save as. File will also temporarily be saved in playwright context's default download location.

        Example usage:
        | New Context      acceptDownloads=True
        | New Page         ${LOGIN_URL}
        | ${dl_promise}    Promise To  Wait For Download
        | Click            \\#file_download
        | ${file_path}=    Wait For  ${dl_promise}
        """
        with self.playwright.grpc_channel() as stub:
            if not saveAs:
                response = stub.WaitForDownload(Request().FilePath())
                logger.debug(response.log)
                return json.loads(response.json)
            else:
                p = Path(saveAs)
                p.resolve()
                response = stub.WaitForDownload(Request().FilePath(path=str(p)))
                logger.debug(response.log)
                return json.loads(response.json)
